@@ -4,6 +4,8 @@ from django.conf.urls.defaults import *
 #from django.views.generic import ListView
 #from coop.org.views import ISDetailView
 #from coop_local.models import Organization
+from coop.feeds import OrganizationUpdates
+
 
 urlpatterns = patterns('',
 
@@ -14,12 +16,19 @@ urlpatterns = patterns('',
     #     )),
 
     url(r'^$', 'coop.org.views.org_list', name="org_list"),
+    url(r'^carto/$', 'coop.org.views.leaflet', name="leaflet"),
+
+    url(r'^feed/$', OrganizationUpdates()),
+
+
     url(r'^global_map$', 'coop.org.views.global_map', name="org_global_map"),
     url(r'^(?P<slug>[\w-]+)/$', 'coop.org.views.org_detail_view', name="org_detail"),
     url(r'^(?P<slug>[\w-]+)/edit/$', 'coop.org.views.org_edit', name="org_edit"),
     
     url(r'^role/(?P<slug>[\w-]+)/$', 'coop.org.views.role_detail', name="role_detail"),
     
+
+    
     #     
     # (r'^(?P<slug>\w+).html$', ISDetailView.as_view(
     #     model=Organization,
